#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable-next-line:no-var-requires
const version = require('./package.json').version;
const os = require("os");
const program = require("commander");
const actions_1 = require("./actions");
if (process.argv.length === 2) {
    console.log('Verifique os comandos com $ teresinha --help');
}
program
    .version(version)
    .command('check')
    .description('Verifica a versão do teresa cli')
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield actions_1.checkUpdate();
    }
    catch (error) {
        console.error(error.message);
    }
}));
program
    .command('update')
    .description('Atualiza o teresa cli')
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield actions_1.download();
    }
    catch (error) {
        console.error(error.message);
    }
}));
program
    .command('start')
    .description('Starta todos seus apps')
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield actions_1.start();
    }
    catch (error) {
        console.error(error.message);
    }
}));
program
    .command('env')
    .description('Configura variáveis de ambiente em massa')
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (os.type() === 'Windows_NT') {
            console.log('Não disponível para Windows');
            return;
        }
        const app = process.argv[3];
        if (!app) {
            console.log('Informe nome do app');
            return;
        }
        const envPath = process.argv[4];
        if (!envPath) {
            console.log('Informe caminho do .env');
            return;
        }
        yield actions_1.env(app, envPath);
    }
    catch (error) {
        console.error(error.message);
        console.error(error);
    }
})).on('--help', () => {
    console.log('');
    console.log('Example:');
    console.log('');
    console.log('  $ teresinha env {nomedoapp} {caminho}');
});
program
    .command('getAllEnvs')
    .description('Copia todas as variáveis de ambiente em massa')
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (os.type() === 'Windows_NT') {
            console.log('Não disponível para Windows');
            return;
        }
        const envPath = process.argv[3];
        if (!envPath) {
            console.log('Informe caminho de onde irá salvar os .env');
            return;
        }
        yield actions_1.getAllEnvs(envPath);
    }
    catch (error) {
        console.error(error.message);
        console.error(error);
    }
})).on('--help', () => {
    console.log('');
    console.log('Example:');
    console.log('');
    console.log('  $ teresinha getAllEnvs {caminho}');
});
program
    .command('setAllEnvs')
    .description('Seta todas as variáveis de ambiente em massa')
    .action(() => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (os.type() === 'Windows_NT') {
            console.log('Não disponível para Windows');
            return;
        }
        const envPath = process.argv[3];
        if (!envPath) {
            console.log('Informe caminho de onde irá copiar os .env');
            return;
        }
        yield actions_1.setAllEnvs(envPath);
    }
    catch (error) {
        console.error(error.message);
        console.error(error);
    }
})).on('--help', () => {
    console.log('');
    console.log('Example:');
    console.log('');
    console.log('  $ teresinha setAllEnvs {caminho}');
});
program.parse(process.argv);
//# sourceMappingURL=index.js.map